@@ -5,6 +5,7 @@
 #include <dbus/dbus.h>
 
 #include <stdio.h>
+#include <stdlib.h>
  
 #include <libhildondesktop/libhildondesktop.h>
 
@@ -55,7 +56,12 @@ static gboolean battery_plugin_on_timeout(gpointer data)
 	}
 	else
 	{
-		battery->percent = libhal_device_get_property_int(ctx, "/org/freedesktop/Hal/devices/bme", "battery.charge_level.percentage", NULL);
+		if ( libhal_device_property_exists(ctx, "/org/freedesktop/Hal/devices/computer_power_supply_battery_bq27200_0", "battery.charge_level.percentage", NULL) )
+			battery->percent = libhal_device_get_property_int(ctx, "/org/freedesktop/Hal/devices/computer_power_supply_battery_bq27200_0", "battery.charge_level.percentage", NULL);
+		else if ( system("pgrep -f ^/usr/sbin/bme_RX-51") == 0 )
+			battery->percent = libhal_device_get_property_int(ctx, "/org/freedesktop/Hal/devices/bme", "battery.charge_level.percentage", NULL);
+		else
+			battery->percent = 0;
 	}
 	
 	//GtkWidget *widget = GTK_WIDGET(data);
