@@ -38,6 +38,13 @@ typedef struct //_BatteryPlugin
 	int percent;
 	gchar* percent_str;
 	
+	gboolean active;
+	
+	gint bat_pos;
+	gfloat font_size;
+	
+	gdouble bat_size;
+	
 	gint timeout_handler;
 } BatteryPlugin;
  
